@@ -12,12 +12,14 @@ class FlaUiError(AttributeError):
     NoElementAttached = "No element attached"
     ElementNameNotFound = "Name '{}' could not be found in element"
     ElementNameNotEquals = "Name from element '{}' is not equals to '{}'"
-    ElementNameDoesNotContainsFromValue = "Name from element '{}' does not contains to '{}'"
+    ElementNameDoesNotContainsFromValue = "Name from element '{}' does not contain '{}'"
     ElementNotClickable = "Element position could not be found because it is hidden."
     ActionNotSupported = "Action not supported"
     ElementExists = "Element '{}' exists"
     ElementVisible = "Element '{}' is visible"
     ElementNotVisible = "Element '{}' is not visible"
+    ElementNotEnabled = "Element '{}' is not enabled"
+    ElementNotDisabled = "Element '{}' is not disabled"
     ElementNotExpandable = "Element '{}' is not expandable"
     NoWindowWithNameFound = "No window with name '{}' found"
     WindowCloseNotSupported = "Close operation only supported for window elements"
