@@ -42,6 +42,7 @@ class Element(ModuleInterface):
         ELEMENT_SHOULD_BE_DISABLED = "ELEMENT_SHOULD_BE_DISABLED"
         WAIT_UNTIL_ELEMENT_IS_HIDDEN = "WAIT_UNTIL_ELEMENT_IS_HIDDEN"
         WAIT_UNTIL_ELEMENT_IS_VISIBLE = "WAIT_UNTIL_ELEMENT_IS_VISIBLE"
+        WAIT_UNTIL_ELEMENT_IS_ENABLED = "WAIT_UNTIL_ELEMENT_IS_ENABLED"
 
     def __init__(self, automation: Any, timeout: int = 1000):
         """
@@ -145,6 +146,10 @@ class Element(ModuleInterface):
             * Values ["xpath", "retries"]
             * Returns : None
 
+          *  Action.WAIT_UNTIL_ELEMENT_IS_ENABLED
+            * Values ["xpath", "retries"]
+            * Returns : None
+
         Raises:
             FlaUiError: If action is not supported.
 
@@ -174,6 +179,8 @@ class Element(ModuleInterface):
             self.Action.WAIT_UNTIL_ELEMENT_IS_HIDDEN: lambda: self._wait_until_element_is_hidden(
                 values["xpath"], values["retries"]),
             self.Action.WAIT_UNTIL_ELEMENT_IS_VISIBLE: lambda: self._wait_until_element_is_visible(
+                values["xpath"], values["retries"]),
+            self.Action.WAIT_UNTIL_ELEMENT_IS_ENABLED: lambda: self._wait_until_element_is_enabled(
                 values["xpath"], values["retries"])
         }
 
@@ -383,6 +390,10 @@ class Element(ModuleInterface):
         Args:
             xpath (String): XPath from element which should be hidden
             retries (Number): Maximum number from retries from wait until
+        
+        Raises:
+            FlaUiError: If node could not be found from xpath.
+            FlaUiError: If node by xpath is visible.
         """
 
         timer = 0
@@ -409,6 +420,10 @@ class Element(ModuleInterface):
         Args:
             xpath (String): XPath from element which should be hidden
             retries (Number): Maximum number from retries from wait until
+        
+        Raises:
+            FlaUiError: If node could not be found from xpath.
+            FlaUiError: If node by xpath is hidden.
         """
 
         timer = 0
@@ -430,6 +445,37 @@ class Element(ModuleInterface):
         self._set_timeout(old_timeout)
         raise FlaUiError(FlaUiError.ElementNotVisible.format(xpath))
 
+    def _wait_until_element_is_enabled(self, xpath: str, retries: int):
+        """Wait until element is enabled or timeout occurs.
+
+        Args:
+            xpath (String): XPath from element which should be hidden
+            retries (Number): Maximum number from retries from wait until
+        
+        Raises:
+            FlaUiError: If node could not be found from xpath.
+            FlaUiError: If node by xpath is not enabled.
+        """
+
+        timer = 0
+        old_timeout = self._timeout
+        self._set_timeout(0)
+
+        while timer < retries:
+
+            try:
+                self._element_should_be_enabled(xpath)
+                self._set_timeout(old_timeout)
+                return
+            except FlaUiError:
+                pass
+
+            time.sleep(1)
+            timer += 1
+
+        self._set_timeout(old_timeout)
+        raise FlaUiError(FlaUiError.ElementNotEnabled.format(xpath))
+
     def _set_timeout(self, timeout: int):
         """Set timeout in seconds.
 
