@@ -1,5 +1,6 @@
 from enum import Enum
 from typing import Optional, Any
+import time
 import FlaUI.Core.Input  # pylint: disable=import-error
 from FlaUI.Core.Exceptions import NoClickablePointException  # pylint: disable=import-error
 from FlaUILibrary.flaui.exception import FlaUiError
@@ -18,17 +19,21 @@ class Mouse(ModuleInterface):
         """
         element: Optional[Any]
         second_element: Optional[Any]
+        timeout_in_ms: Optional[int]
 
     class Action(Enum):
         """Supported actions for execute action implementation."""
         LEFT_CLICK = "LEFT_CLICK"
         RIGHT_CLICK = "RIGHT_CLICK"
         DOUBLE_CLICK = "DOUBLE_CLICK"
+        LEFT_CLICK_HOLD = "LEFT_CLICK_HOLD"
+        RIGHT_CLICK_HOLD = "RIGHT_CLICK_HOLD"
+        DOUBLE_CLICK_HOLD = "DOUBLE_CLICK_HOLD"
         MOVE_TO = "MOVE_TO"
         DRAG_AND_DROP = "DRAG_AND_DROP"
 
     @staticmethod
-    def create_value_container(element=None, second_element=None):
+    def create_value_container(element=None, second_element=None, timeout_in_ms=None):
         """
         Helper to create container object.
 
@@ -36,7 +41,7 @@ class Mouse(ModuleInterface):
             element (Object): Element to click
             second_element (Object): To Element from drag and drop
         """
-        return Mouse.Container(element=element, second_element=second_element)
+        return Mouse.Container(element=element, second_element=second_element, timeout_in_ms=timeout_in_ms)
 
     def execute_action(self, action: Action, values: Container):
         """If action is not supported an ActionNotSupported error will be raised.
@@ -47,6 +52,10 @@ class Mouse(ModuleInterface):
             * Values ["element"] : UIA3 Element from FlaUI to interact
             * Returns : None
 
+          *  Action.LEFT_CLICK_HOLD, RIGHT_CLICK_HOLD, DOUBLE_CLICK_HOLD,
+            * Values ["element","timeout"] : UIA3 Element from FlaUI to interact
+            * Returns : None
+
          *  Action.DRAG_AND_DROP
             * Values ["element", "second_element"] : UIA3 Elements from FlaUI to drag and drop
             * Returns : None
@@ -63,6 +72,9 @@ class Mouse(ModuleInterface):
             self.Action.LEFT_CLICK: lambda: self._click(values["element"]),
             self.Action.RIGHT_CLICK: lambda: self._right_click(values["element"]),
             self.Action.DOUBLE_CLICK: lambda: self._double_click(values["element"]),
+            self.Action.LEFT_CLICK_HOLD: lambda: self._click_hold(values["element"], values["timeout_in_ms"]),
+            self.Action.RIGHT_CLICK_HOLD: lambda: self._right_click_hold(values["element"], values["timeout_in_ms"]),
+            self.Action.DOUBLE_CLICK_HOLD: lambda: self._double_click_hold(values["element"], values["timeout_in_ms"]),
             self.Action.MOVE_TO: lambda: self._move_to(values["element"]),
             self.Action.DRAG_AND_DROP: lambda: self._drag_and_drop(values["element"], values["second_element"])
         }
@@ -76,6 +88,16 @@ class Mouse(ModuleInterface):
         except NoClickablePointException:
             raise FlaUiError(FlaUiError.ElementNotClickable) from None
 
+    @staticmethod
+    def _click_hold(element: Any, timeout_in_ms: int):
+        try:
+            FlaUI.Core.Input.Mouse.Position = element.GetClickablePoint()
+        except NoClickablePointException:
+            raise FlaUiError(FlaUiError.ElementNotClickable) from None
+        FlaUI.Core.Input.Mouse.Down()
+        time.sleep(float(timeout_in_ms)/1000)
+        FlaUI.Core.Input.Mouse.Up()
+
     @staticmethod
     def _right_click(element: Any):
         try:
@@ -83,6 +105,16 @@ class Mouse(ModuleInterface):
         except NoClickablePointException:
             raise FlaUiError(FlaUiError.ElementNotClickable) from None
 
+    @staticmethod
+    def _right_click_hold(element: Any, timeout_in_ms: int):
+        try:
+            FlaUI.Core.Input.Mouse.Position = element.GetClickablePoint()
+        except NoClickablePointException:
+            raise FlaUiError(FlaUiError.ElementNotClickable) from None
+        FlaUI.Core.Input.Mouse.Down(FlaUI.Core.Input.MouseButton.Right)
+        time.sleep(float(timeout_in_ms)/1000)
+        FlaUI.Core.Input.Mouse.Up(FlaUI.Core.Input.MouseButton.Right)
+
     @staticmethod
     def _double_click(element: Any):
         try:
@@ -90,6 +122,18 @@ class Mouse(ModuleInterface):
         except NoClickablePointException:
             raise FlaUiError(FlaUiError.ElementNotClickable) from None
 
+    @staticmethod
+    def _double_click_hold(element: Any, timeout_in_ms: int):
+        try:
+            FlaUI.Core.Input.Mouse.Position = element.GetClickablePoint()
+        except NoClickablePointException:
+            raise FlaUiError(FlaUiError.ElementNotClickable) from None
+        FlaUI.Core.Input.Mouse.Down()
+        FlaUI.Core.Input.Mouse.Up()
+        FlaUI.Core.Input.Mouse.Down()
+        time.sleep(float(timeout_in_ms)/1000)
+        FlaUI.Core.Input.Mouse.Up()
+
     @staticmethod
     def _move_to(element: Any):
         try:
